==> core-react-0.8.0.tgz: package/es/Popover/index.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import ReactDOM from 'react-dom';
import cx from 'classnames';
import PopoverContent from './PopoverContent';
 // todo remove listener after done

window.addEventListener('click', function () {
  var openedPopoverInContext = Popover[Popover.OPENED_POPOVER];
  openedPopoverInContext && openedPopoverInContext.close();
});

var Popover = /*#__PURE__*/function (_Component) {
  _inherits(Popover, _Component);

  function Popover(props) {
    var _this;

    _classCallCheck(this, Popover);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Popover).call(this));

    _defineProperty(_assertThisInitialized(_this), "open", function () {
      var _this$props = _this.props,
          shouldOpen = _this$props.shouldOpen,
          onToggle = _this$props.onToggle;

      if (!shouldOpen || shouldOpen()) {
        _this.setState({
          open: true
        });

        onToggle && onToggle(true);

        var _assertThisInitialize = _assertThisInitialized(_this),
            openedPopoverInContext = _assertThisInitialize.openedPopoverInContext;

        if (openedPopoverInContext && openedPopoverInContext !== _assertThisInitialized(_this)) {
          openedPopoverInContext.close();
        }

        _this.openedPopoverInContext = _assertThisInitialized(_this);
      }
    });

    _defineProperty(_assertThisInitialized(_this), "close", function () {
      if (!_this.state.open) return;
      var _this$props2 = _this.props,
          shouldClose = _this$props2.shouldClose,
          onToggle = _this$props2.onToggle;

      if (!shouldClose || shouldClose()) {
        _this.setState({
          open: false
        });

        onToggle && onToggle(false);

        if (_this.openedPopoverInContext === _assertThisInitialized(_this)) {
          _this.openedPopoverInContext = null;
        }

        _this.closeChildOpenedPopover();
      }
    });

    _this.state = {
      open: props.open || false
    };
    return _this;
  }

  _createClass(Popover, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      if (this.state.open) {
        this.renderContent();
      }
    }
  }, {
    key: "componentWillReceiveProps",
    value: function componentWillReceiveProps(nextProps) {
      'open' in nextProps && this.setState({
        open: nextProps.open
      });
    }
  }, {
    key: "componentDidUpdate",
    value: function componentDidUpdate(prevProps, prevState) {
      if (this.state.open) {
        this.renderContent();
      } else {
        if (prevState.open) {
          ReactDOM.findDOMNode(this.popoverContent).style.display = 'none';
        }
      }
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      if (this.containerNode) {
        ReactDOM.unmountComponentAtNode(this.containerNode);
        document.body.removeChild(this.containerNode);
      }

      var openedPopoverInContext = this.openedPopoverInContext;

      if (openedPopoverInContext === this) {
        this.openedPopoverInContext = null;
      }
    } // 当前 popover 所在的浮层（或全局）的打开的 popover，实现打开唯一性

  }, {
    key: "closeChildOpenedPopover",
    value: function closeChildOpenedPopover() {
      var childOpenedPopover = this.popoverContent && this.popoverContent[Popover.OPENED_POPOVER];
      childOpenedPopover && childOpenedPopover.close();
    }
  }, {
    key: "renderContent",
    value: function renderContent() {
      var _this2 = this;

      if (!this.containerNode) {
        this.containerNode = document.createElement('div');
        document.body.appendChild(this.containerNode);
      }

      var triggerNode = ReactDOM.findDOMNode(this);

      this.renderContent = function () {
        var _this2$props = _this2.props,
            triggerMode = _this2$props.triggerMode,
            content = _this2$props.content,
            open = _this2$props.open,
            onToggle = _this2$props.onToggle,
            shouldOpen = _this2$props.shouldOpen,
            shouldClose = _this2$props.shouldClose,
            disabled = _this2$props.disabled,
            aligned = _this2$props.aligned,
            other = _objectWithoutProperties(_this2$props, ["triggerMode", "content", "open", "onToggle", "shouldOpen", "shouldClose", "disabled", "aligned"]);

        other.onClick = function (e) {
          e.stopPropagation();

          _this2.closeChildOpenedPopover();
        };

        if (triggerMode === 'hover') {
          other.onMouseEnter = function () {
            clearTimeout(_this2.closeTimer);
          };

          other.onMouseLeave = function () {
            _this2.closeTimer = setTimeout(function () {
              return _this2.close();
            }, Popover.LAZY_DURATION);
          };
        }

        if (aligned) {
          other.style = Object.assign(other.style || {}, {
            width: triggerNode.offsetWidth
          });
        }

        ReactDOM.render(React.createElement(PopoverContent, _extends({
          ref: function ref(instance) {
            return _this2.popoverContent = instance;
          },
          triggerNode: triggerNode,
          triggerMode: triggerMode
        }, other), content), _this2.containerNode);
      };

      this.renderContent();
    }
  }, {
    key: "render",
    value: function render() {
      var _this3 = this;

      var _this$props3 = this.props,
          children = _this$props3.children,
          triggerMode = _this$props3.triggerMode,
          disabled = _this$props3.disabled;
      var open = this.state.open;
      var triggerProps = {
        className: cx(children.props.className, "".concat("waui", "-popover__trigger"), _defineProperty({}, "".concat("waui", "-popover__trigger_disabled"), disabled))
      };

      if (!disabled) {
        if (triggerMode === 'hover') {
          triggerProps.onMouseEnter = function () {
            clearTimeout(_this3.closeTimer);
            _this3.openTimer = setTimeout(_this3.open, Popover.LAZY_DURATION);
            children.props.onMouseEnter && children.props.onMouseEnter();
          };

          triggerProps.onMouseLeave = function () {
            clearTimeout(_this3.openTimer);
            _this3.closeTimer = setTimeout(_this3.close, Popover.LAZY_DURATION);
            children.props.onMouseLeave && children.props.onMouseLeave();
          };
        } else {
          triggerProps.onClick = function (e) {
            e.stopPropagation();

            _this3[open ? 'close' : 'open']();

            children.props.onClick && children.props.onClick();
          };
        }
      }

      return React.cloneElement(children, triggerProps);
    }
  }, {
    key: "openedPopoverInContext",
    get: function get() {
      return (this.context.popoverContent || Popover)[Popover.OPENED_POPOVER];
    },
    set: function set(popover) {
      (this.context.popoverContent || Popover)[Popover.OPENED_POPOVER] = popover;
    }
    /**
     * @public
     * @name popover.open()
     * @description 打开浮层
     */

  }]);

  return Popover;
}(Component);

_defineProperty(Popover, "LAZY_DURATION", 150);

_defineProperty(Popover, "OPENED_POPOVER", Symbol('OPENED_POPOVER'));

Popover.contextTypes = {
  popoverContent: PropTypes.instanceOf(PopoverContent)
};
Popover.defaultProps = {
  direction: 'up',
  triggerMode: 'hover'
};
Popover.propTypes = {
  children: PropTypes.element.isRequired,
  triggerMode: PropTypes.oneOf(['click', 'hover']),
  content: PropTypes.node,
  direction: PropTypes.oneOf(['up', 'down', 'left', 'right']),
  align: PropTypes.oneOf(['top', 'right', 'bottom', 'left', 'middle']),
  open: PropTypes.bool,
  onToggle: PropTypes.func,
  shouldOpen: PropTypes.func,
  shouldClose: PropTypes.func,
  disabled: PropTypes.bool,
  aligned: PropTypes.bool
};
export default Popover;

==> core-react-0.8.2.tgz: package/es/Popover/index.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import ReactDOM from 'react-dom';
import cx from 'classnames';
import PopoverContent from './PopoverContent';
 // todo remove listener after done

window.addEventListener('click', function () {
  var openedPopoverInContext = Popover[Popover.OPENED_POPOVER];
  openedPopoverInContext && openedPopoverInContext.close();
});

var Popover = /*#__PURE__*/function (_Component) {
  _inherits(Popover, _Component);

  function Popover(props) {
    var _this;

    _classCallCheck(this, Popover);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Popover).call(this));

    _defineProperty(_assertThisInitialized(_this), "open", function () {
      var _this$props = _this.props,
          shouldOpen = _this$props.shouldOpen,
          onToggle = _this$props.onToggle;

      if (!shouldOpen || shouldOpen()) {
        _this.setState({
          open: true
        });

        onToggle && onToggle(true);

        var _assertThisInitialize = _assertThisInitialized(_this),
            openedPopoverInContext = _assertThisInitialize.openedPopoverInContext;

        if (openedPopoverInContext && openedPopoverInContext !== _assertThisInitialized(_this)) {
          openedPopoverInContext.close();
        }

        _this.openedPopoverInContext = _assertThisInitialized(_this);
      }
    });

    _defineProperty(_assertThisInitialized(_this), "close", function () {
      if (!_this.state.open) return;
      var _this$props2 = _this.props,
          shouldClose = _this$props2.shouldClose,
          onToggle = _this$props2.onToggle;

      if (!shouldClose || shouldClose()) {
        _this.setState({
          open: false
        });

        onToggle && onToggle(false);

        if (_this.openedPopoverInContext === _assertThisInitialized(_this)) {
          _this.openedPopoverInContext = null;
        }

        _this.closeChildOpenedPopover();
      }
    });

    _this.state = {
      open: props.open || false
    };
    return _this;
  }

  _createClass(Popover, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      if (this.state.open) {
        this.renderContent();
      }
    }
  }, {
    key: "componentWillReceiveProps",
    value: function componentWillReceiveProps(nextProps) {
      'open' in nextProps && this.setState({
        open: nextProps.open
      });
    }
  }, {
    key: "componentDidUpdate",
    value: function componentDidUpdate(prevProps, prevState) {
      if (this.state.open) {
        this.renderContent();
      } else {
        if (prevState.open) {
          ReactDOM.findDOMNode(this.popoverContent).style.display = 'none';
        }
      }
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      if (this.containerNode) {
        ReactDOM.unmountComponentAtNode(this.containerNode);
        document.body.removeChild(this.containerNode);
      }

      var openedPopoverInContext = this.openedPopoverInContext;

      if (openedPopoverInContext === this) {
        this.openedPopoverInContext = null;
      }
    } // 当前 popover 所在的浮层（或全局）的打开的 popover，实现打开唯一性

  }, {
    key: "closeChildOpenedPopover",
    value: function closeChildOpenedPopover() {
      var childOpenedPopover = this.popoverContent && this.popoverContent[Popover.OPENED_POPOVER];
      childOpenedPopover && childOpenedPopover.close();
    }
  }, {
    key: "renderContent",
    value: function renderContent() {
      var _this2 = this;

      if (!this.containerNode) {
        this.containerNode = document.createElement('div');
        document.body.appendChild(this.containerNode);
      }

      var triggerNode = ReactDOM.findDOMNode(this);

      this.renderContent = function () {
        var _this2$props = _this2.props,
            triggerMode = _this2$props.triggerMode,
            content = _this2$props.content,
            open = _this2$props.open,
            onToggle = _this2$props.onToggle,
            shouldOpen = _this2$props.shouldOpen,
            shouldClose = _this2$props.shouldClose,
            disabled = _this2$props.disabled,
            aligned = _this2$props.aligned,
            other = _objectWithoutProperties(_this2$props, ["triggerMode", "content", "open", "onToggle", "shouldOpen", "shouldClose", "disabled", "aligned"]);

        other.onClick = function (e) {
          e.stopPropagation();

          _this2.closeChildOpenedPopover();
        };

        if (triggerMode === 'hover') {
          other.onMouseEnter = function () {
            clearTimeout(_this2.closeTimer);
          };

          other.onMouseLeave = function () {
            _this2.closeTimer = setTimeout(function () {
              return _this2.close();
            }, Popover.LAZY_DURATION);
          };
        }

        if (aligned) {
          other.style = Object.assign(other.style || {}, {
            width: triggerNode.offsetWidth
          });
        }

        ReactDOM.render( /*#__PURE__*/React.createElement(PopoverContent, _extends({
          ref: function ref(instance) {
            return _this2.popoverContent = instance;
          },
          triggerNode: triggerNode,
          triggerMode: triggerMode
        }, other), content), _this2.containerNode);
      };

      this.renderContent();
    }
  }, {
    key: "render",
    value: function render() {
      var _this3 = this;

      var _this$props3 = this.props,
          children = _this$props3.children,
          triggerMode = _this$props3.triggerMode,
          disabled = _this$props3.disabled;
      var open = this.state.open;
      var triggerProps = {
        className: cx(children.props.className, "".concat("waui", "-popover__trigger"), _defineProperty({}, "".concat("waui", "-popover__trigger_disabled"), disabled))
      };

      if (!disabled) {
        if (triggerMode === 'hover') {
          triggerProps.onMouseEnter = function () {
            clearTimeout(_this3.closeTimer);
            _this3.openTimer = setTimeout(_this3.open, Popover.LAZY_DURATION);
            children.props.onMouseEnter && children.props.onMouseEnter();
          };

          triggerProps.onMouseLeave = function () {
            clearTimeout(_this3.openTimer);
            _this3.closeTimer = setTimeout(_this3.close, Popover.LAZY_DURATION);
            children.props.onMouseLeave && children.props.onMouseLeave();
          };
        } else {
          triggerProps.onClick = function (e) {
            e.stopPropagation();

            _this3[open ? 'close' : 'open']();

            children.props.onClick && children.props.onClick();
          };
        }
      }

      return React.cloneElement(children, triggerProps);
    }
  }, {
    key: "openedPopoverInContext",
    get: function get() {
      return (this.context.popoverContent || Popover)[Popover.OPENED_POPOVER];
    },
    set: function set(popover) {
      (this.context.popoverContent || Popover)[Popover.OPENED_POPOVER] = popover;
    }
    /**
     * @public
     * @name popover.open()
     * @description 打开浮层
     */

  }]);

  return Popover;
}(Component);

_defineProperty(Popover, "LAZY_DURATION", 150);

_defineProperty(Popover, "OPENED_POPOVER", Symbol('OPENED_POPOVER'));

Popover.contextTypes = {
  popoverContent: PropTypes.instanceOf(PopoverContent)
};
Popover.defaultProps = {
  direction: 'up',
  triggerMode: 'hover'
};
Popover.propTypes = {
  children: PropTypes.element.isRequired,
  triggerMode: PropTypes.oneOf(['click', 'hover']),
  content: PropTypes.node,
  direction: PropTypes.oneOf(['up', 'down', 'left', 'right']),
  align: PropTypes.oneOf(['top', 'right', 'bottom', 'left', 'middle']),
  open: PropTypes.bool,
  onToggle: PropTypes.func,
  shouldOpen: PropTypes.func,
  shouldClose: PropTypes.func,
  disabled: PropTypes.bool,
  aligned: PropTypes.bool
};
export default Popover;
